@@ -644,18 +644,32 @@ def _get_c_data_type(value):
     elif numpy.isscalar(value):
         if isinstance(value, (str, bytes)):
             return _lib.harp_type_string
-        elif numpy.can_cast(value, numpy.int8):
+        try:
+            numpy.array(value, dtype=numpy.int8)
             return _lib.harp_type_int8
-        elif numpy.can_cast(value, numpy.int16):
+        except Exception:
+            pass
+        try:
+            numpy.array(value, dtype=numpy.int16)
             return _lib.harp_type_int16
-        elif numpy.can_cast(value, numpy.int32):
+        except Exception:
+            pass
+        try:
+            numpy.array(value, dtype=numpy.int32)
             return _lib.harp_type_int32
-        elif numpy.can_cast(value, numpy.float32):
+        except Exception:
+            pass
+        try:
+            numpy.array(value, dtype=numpy.float32)
             return _lib.harp_type_float
-        elif numpy.can_cast(value, numpy.float64):
+        except Exception:
+            pass
+        try:
+            numpy.array(value, dtype=numpy.float64)
             return _lib.harp_type_double
-        else:
-            raise UnsupportedTypeError("unsupported type %r" % value.__class__.__name__)
+        except Exception:
+            pass
+        raise UnsupportedTypeError("unsupported type %r" % value.__class__.__name__)
     else:
         raise UnsupportedTypeError("unsupported type %r" % value.__class__.__name__)
 
@@ -1438,7 +1452,7 @@ def _extend_variable_for_dim(variable, dim_index, new_length):
     shape = list(variable.data.shape)
     shape[dim_index] = new_length - shape[dim_index]
     filler = numpy.empty(shape, dtype=variable.data.dtype)
-    filler[:] = numpy.NAN
+    filler[:] = numpy.nan
     variable.data = numpy.concatenate([variable.data, filler], axis=dim_index)
 
 
@@ -1515,7 +1529,7 @@ def execute_operations(products, operations="", post_operations=""):
         # Create C product.
         c_product_ptr = _ffi.new("harp_product **")
         if _lib.harp_product_new(c_product_ptr) != 0:
-            raise harp.CLibraryError()
+            raise CLibraryError()
         try:
             _export_product(products, c_product_ptr[0])
             if _lib.harp_product_execute_operations(c_product_ptr[0], _encode_string(operations)) != 0:
